@@ -62,12 +62,14 @@ G_DEFINE_TYPE (HDDesktop, hd_desktop, G_TYPE_OBJECT);
 #define HD_DESKTOP_CONFIG_FILE         "desktop.conf"
 #define HD_DESKTOP_CONFIG_USER_PATH    ".osso/hildon-desktop/"
 
-#define HD_DESKTOP_PING_TIMEOUT_MESSAGE_STRING       _( "qgn_nc_apkil_notresponding" )
-#define HD_DESKTOP_PING_TIMEOUT_RESPONSE_STRING      _( "qgn_ib_apkil_responded" )
-#define HD_DESKTOP_PING_TIMEOUT_KILL_FAILURE_STRING  _( "" )
+#define _L10N(s) dgettext(GETTEXT_PACKAGE, s)
 
-#define HD_DESKTOP_PING_TIMEOUT_BUTTON_OK_STRING     _( "qgn_bd_apkil_ok" )
-#define HD_DESKTOP_PING_TIMEOUT_BUTTON_CANCEL_STRING _( "qgn_bd_apkil_cancel" )
+#define HD_DESKTOP_PING_TIMEOUT_MESSAGE_STRING       _L10N("qgn_nc_apkil_notresponding")
+#define HD_DESKTOP_PING_TIMEOUT_RESPONSE_STRING      _L10N( "qgn_ib_apkil_responded" )
+#define HD_DESKTOP_PING_TIMEOUT_KILL_FAILURE_STRING  _L10N( "" )
+
+#define HD_DESKTOP_PING_TIMEOUT_BUTTON_OK_STRING     _L10N( "qgn_bd_apkil_ok" )
+#define HD_DESKTOP_PING_TIMEOUT_BUTTON_CANCEL_STRING _L10N( "qgn_bd_apkil_cancel" )
 
 typedef struct 
 {
@@ -141,6 +143,7 @@ static void
 hd_desktop_application_frozen (HDWM *hdwm, HDWMWindow *win, gpointer data)
 {
   GtkWidget *note;
+  g_debug ("application frozen");
 
   HDWMApplication *app = hd_wm_window_get_application (win);
 
@@ -267,8 +270,8 @@ hd_desktop_launch_banner_timeout (gpointer data)
   t2 = (long unsigned int) current_time.tv_sec;
   time_left = (guint) (t2 - t1);
 
-  if (time_left >= current_banner_timeout + 4)/* ||
-      hd_wm_application_has_windows (info->app))*/
+  if (time_left >= current_banner_timeout + 4 ||
+      hd_wm_application_has_windows (info->app))
   {
     hd_desktop_launch_banner_close (NULL, info);
     return FALSE;
