@@ -177,7 +177,7 @@ hn_others_button_init (HNOthersButton *button)
   gtk_widget_show_all (priv->button);
 
   hdwm = hd_wm_get_singleton ();
-  hd_wm_set_all_menu_button (hdwm, priv->button);
+  hd_wm_set_all_menu_button (hdwm, G_OBJECT (priv->button));
 
   g_signal_connect (G_OBJECT (priv->button), 
                     "button-press-event",
@@ -1018,23 +1018,20 @@ hn_others_button_register_monitors (HNOthersButton * button)
   gchar	*file = NULL;
   gchar *conf_file;
 
-  conf_file = g_build_filename (g_get_home_dir (), USER_MENU_FILE, NULL);
+  conf_file = g_build_filename (g_get_home_dir (), USER_MENU_DIR, MENU_FILE, NULL);
  
   /* We copy SYSTEMWIDE_MENU_FILE to always track the changes */
   if (!g_file_test (conf_file, G_FILE_TEST_EXISTS))
-    if (g_file_get_contents (SYSTEMWIDE_MENU_FILE, &file, NULL, NULL))
+    if (g_file_get_contents (HD_DESKTOP_MENU_PATH "/" MENU_FILE, &file, NULL, NULL))
     {
-      g_debug ("I couldn't get contents");
-      g_file_set_contents (USER_MENU_FILE, file, -1, NULL);
+      g_file_set_contents (conf_file, file, -1, NULL);
     }
   
   g_free (file);
   
   /* Watch systemwide menu conf */
-  dir = g_path_get_dirname (SYSTEMWIDE_MENU_FILE);
- 
   if (gnome_vfs_monitor_add (&button->priv->system_dir_monitor, 
-                             dir,
+                             HD_DESKTOP_MENU_PATH,
                              GNOME_VFS_MONITOR_DIRECTORY,
                              (GnomeVFSMonitorCallback) hn_others_button_dir_changed,
                              button) != GNOME_VFS_OK)
@@ -1044,38 +1041,32 @@ hn_others_button_register_monitors (HNOthersButton * button)
       	       "for systemwide menu conf." );
   }
 
-  g_free (dir);
+  /* Have to get the directory from the path because the USER_MENU_FILE
+     define might contain directory (it does, in fact). */
+  dir = g_path_get_dirname (conf_file);
   
-  /* Watch user specific menu conf */
-  if (g_get_home_dir ())
-  {    
-    /* Have to get the directory from the path because the USER_MENU_FILE
-       define might contain directory (it does, in fact). */
-    dir = g_path_get_dirname (conf_file);
-    
-    g_mkdir (dir, 0755);
+  g_mkdir (dir, 0755);
 
-    if (dir && *dir)
-    {
-      if (gnome_vfs_monitor_add (&button->priv->home_dir_monitor, 
-                                 dir,
-                                 GNOME_VFS_MONITOR_DIRECTORY,
-                                 (GnomeVFSMonitorCallback) hn_others_button_dir_changed,
-                                 button) != GNOME_VFS_OK)
-      {
-        g_warning ("Others_menu_initialize_menu: "
-      	           "failed setting monitor callback "
-      	           "for user specific menu conf." );
-      }
-    }
-    else
+  if (dir && *dir)
+  {
+    if (gnome_vfs_monitor_add (&button->priv->home_dir_monitor, 
+                               dir,
+                               GNOME_VFS_MONITOR_DIRECTORY,
+                               (GnomeVFSMonitorCallback) hn_others_button_dir_changed,
+                               button) != GNOME_VFS_OK)
     {
       g_warning ("Others_menu_initialize_menu: "
-    	         "failed to create directory '%s'", dir);
+    	         "failed setting monitor callback "
+    	         "for user specific menu conf." );
     }
-
-    g_free (dir);
   }
+  else
+  {
+    g_warning ("Others_menu_initialize_menu: "
+  	       "failed to create directory '%s'", dir);
+  }
+
+  g_free (dir);
       
   g_free (conf_file);
   
@@ -1091,6 +1082,19 @@ hn_others_button_register_monitors (HNOthersButton * button)
       	       "failed setting monitor callback "
       	       "for .desktop directory." );
   }
+
+  /* Monitor the hildon .desktop directories, so we can regenerate the 
+   * menu when a new application is installed */
+  if (gnome_vfs_monitor_add (&button->priv->desktop_dir_monitor, 
+                             HD_DESKTOP_ENTRY_PATH "/hildon",
+                             GNOME_VFS_MONITOR_DIRECTORY,
+                             (GnomeVFSMonitorCallback) hn_others_button_dir_changed,
+                             button) != GNOME_VFS_OK)
+  {
+    g_warning ("Others_menu_initialize_menu: "
+      	       "failed setting monitor callback "
+      	       "for .desktop directory." );
+  }
 }
 
 void
